**WaffleConf** is a *Flask* extension for allowing configuration variable
modification during runtime by storing them in a database and refreshing the
application configuration everytime any of these change.

**Released under GPLv2+ license.**

# Contents

- **[Quickstart](quickstart.md)**
- **[Multiprocess deployments](multiproc.md)**
- **[Configuration](configuration.md)**
- **API**
    - **[Model](api/model.md)**
    - **[Store](api/store.md)**
    - **[WaffleConf](api/waffleconf.md)**
    - **[Views](api/views.md)**
    - **[Utils](api/util.md)**

# Links

- **Source:** <https://github.com/rmed/flask-waffleconf>
- **Issues:** <https://github.com/rmed/flask-waffleconf/issues>
